From: Raphaƫl Gertz <git@rapsys.eu>
Date: Thu, 1 Feb 2024 02:10:40 +0000 (+0100)
Subject: Add last raw file
X-Git-Tag: 2.0.5
X-Git-Url: https://git.rapsys.eu/acme/commitdiff_plain/refs/heads/master?ds=sidebyside

Add last raw file
Do not remove extra certificate anymore
---

diff --git a/Acme.pm b/Acme.pm
index a27e385..2360380 100644
--- a/Acme.pm
+++ b/Acme.pm
@@ -1063,11 +1063,14 @@ sub issue {
 		write_file($file, $content);
 	}
 
-	# Remove first multi-line jump
-	$content =~ s/\n\n/\n/;
+	# Write to raw cert file
+	write_file($self->{domain}{cert}.'.raw', $content);
+
+	# Remove multi-line jump
+	$content =~ s/\n\n/\n/s;
 
 	# Remove ISRG Root X1 certificate signed by DST Root CA X3 present after second multi-line jump
-	$content =~ s/\n\n.*//s;
+	#$content =~ s/\n\n.*//s;
 
 	# Remove trailing line jump
 	chomp $content;